/**
 * Copyright 2011 Shopzilla.com
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package com.shopzilla.api.client.model;

import org.apache.commons.lang.builder.EqualsBuilder;
import org.apache.commons.lang.builder.HashCodeBuilder;

import java.util.Collections;
import java.util.List;

/**
 * @author sscanlon
 */
public class Category {

    private Long id;
    private String name;
    private String URL;
    private Double probability;

    private List<Category> children = Collections.emptyList();
    private List<Category> ancestors = Collections.emptyList();

    @Override
    public int hashCode() {
        return new HashCodeBuilder().append(id).toHashCode();
    }

    @Override
    public boolean equals(Object o) {
        if (o == this) {
            return true;
        }
        if (o == null || !(o instanceof Category)) {
            return false;
        }
        Category rhs = (Category) o;
        return new EqualsBuilder()
                .append(id, rhs.id)
                .isEquals();
    }


    @Override
    public String toString() {
        return "Category{" +
                "ancestors=" + ancestors +
                ", id=" + id +
                ", name='" + name + '\'' +
                ", URL='" + URL + '\'' +
                ", probability=" + probability +
                ", children=" + children +
                '}';
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getURL() {
        return URL;
    }

    public void setURL(String uRL) {
        URL = uRL;
    }

    public List<Category> getChildren() {
        return children;
    }

    public void setChildren(List<Category> children) {
        this.children = children;
    }

    public List<Category> getAncestors() {
        return ancestors;
    }

    public void setAncestors(List<Category> ancestors) {
        this.ancestors = ancestors;
    }

    public Double getProbability() {
        return probability;
    }

    public void setProbability(Double probability) {
        this.probability = probability;
    }
}
